@@ -161,31 +161,7 @@ def add(request, form_class=DirectoryForm, template_name="directories/add.html")
                 # set the expiration date
                 directory.expiration_dt = directory.activation_dt + timedelta(days=directory.requested_duration)
 
-            # We set the logo to None temporarily because we need
-            # the PK when we save to get the filepath of the file
-            logo = directory.logo
-            directory.logo = None
-
-            directory = update_perms_and_save(request, form, directory)
-
-            # directory now has a pk, so we can reassign the logo
-            # and resave
-            directory.logo = logo
-
-            if directory.logo:
-                directory.logo.file.seek(0)
-
-                directory.save(log=False)
-
-                if settings.USE_S3_STORAGE:
-                    resize_s3_image(directory.logo.name)
-                else:
-                    try:
-                        logo = Image.open(directory.logo.path)
-                        logo.thumbnail((200,200),Image.ANTIALIAS)
-                        logo.save(directory.logo.path)
-                    except:
-                        pass                
+            directory = update_perms_and_save(request, form, directory)               
                         
             # create invoice
             directory_set_inv_payment(request.user, directory, pricing)
